/*
* Copyright (C) The Community OpenORB Project. All rights reserved.
*
* This software is published under the terms of The OpenORB Community Software
* License version 1.0, a copy of which has been included with this distribution
* in the LICENSE.txt file.
*/
                                                                                                                                                   
#include <jni.h>
#include <stdio.h>

#ifndef _Included_org_openorb_rmi_system_DeserializationKernelNative
#define _Included_org_openorb_rmi_system_DeserializationKernelNative

#ifdef __cplusplus
extern "C"
{
#endif

/*
 * Class:     org_openorb_orb_rmi_DeserializationKernelNative
 * Method:    nativeAllocateNewObject
 * Signature: (Ljava/lang/Class;Ljava/lang/Class;)Ljava/lang/Object;
 */
JNIEXPORT jobject JNICALL Java_org_openorb_orb_rmi_DeserializationKernelNative_nativeAllocateNewObject
 (JNIEnv * env, jclass this, jclass aclass, jclass initclass)
{
    return (*env)->AllocObject(env, aclass);
}

/*
 * Class:     org_openorb_orb_rmi_DeserializationKernelNative
 * Method:    nativeSetObjectField
 * Signature: (Ljava/lang/Class;Ljava/lang/String;Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_org_openorb_orb_rmi_DeserializationKernelNative_nativeSetObjectField
  (JNIEnv *env, jclass this, jclass clz, jstring fName, jobject obj, jobject val, jstring fSig)
{
    const char* strFieldName = (*env)->GetStringUTFChars(env, fName, 0L);
    const char* strFieldSig = (*env)->GetStringUTFChars(env, fSig, 0L);

    jfieldID fieldID = (*env)->GetFieldID(env, clz, strFieldName, strFieldSig);

    (*env)->ReleaseStringUTFChars(env, fName, strFieldName);
    (*env)->ReleaseStringUTFChars(env, fSig, strFieldSig);

    (*env)->SetObjectField(env, obj, fieldID, val);
}

/*
 * Class:     org_openorb_orb_rmi_DeserializationKernelNative
 * Method:    nativeSetBooleanField
 * Signature: (Ljava/lang/Class;Ljava/lang/String;Ljava/lang/Object;ZLjava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_org_openorb_orb_rmi_DeserializationKernelNative_nativeSetBooleanField
  (JNIEnv *env, jclass this, jclass clz, jstring fName, jobject obj, jboolean val, jstring fSig)
{
    const char* strFieldName = (*env)->GetStringUTFChars(env, fName, 0L);
    const char* strFieldSig = (*env)->GetStringUTFChars(env, fSig, 0L);

    jfieldID fieldID = (*env)->GetFieldID(env, clz, strFieldName, strFieldSig);

    (*env)->ReleaseStringUTFChars(env, fName, strFieldName);
    (*env)->ReleaseStringUTFChars(env, fSig, strFieldSig);

    (*env)->SetBooleanField(env, obj, fieldID, val);
}

/*
 * Class:     org_openorb_orb_rmi_DeserializationKernelNative
 * Method:    nativeSetByteField
 * Signature: (Ljava/lang/Class;Ljava/lang/String;Ljava/lang/Object;BLjava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_org_openorb_orb_rmi_DeserializationKernelNative_nativeSetByteField
  (JNIEnv *env, jclass this, jclass clz, jstring fName, jobject obj, jbyte val, jstring fSig)
{
    const char* strFieldName = (*env)->GetStringUTFChars(env, fName, 0L);
    const char* strFieldSig = (*env)->GetStringUTFChars(env, fSig, 0L);

    jfieldID fieldID = (*env)->GetFieldID(env, clz, strFieldName, strFieldSig);

    (*env)->ReleaseStringUTFChars(env, fName, strFieldName);
    (*env)->ReleaseStringUTFChars(env, fSig, strFieldSig);

    (*env)->SetByteField(env, obj, fieldID, val);
}

/*
 * Class:     org_openorb_orb_rmi_DeserializationKernelNative
 * Method:    nativeSetCharField
 * Signature: (Ljava/lang/Class;Ljava/lang/String;Ljava/lang/Object;CLjava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_org_openorb_orb_rmi_DeserializationKernelNative_nativeSetCharField
  (JNIEnv *env, jclass this, jclass clz, jstring fName, jobject obj, jchar val, jstring fSig)
{
    const char* strFieldName = (*env)->GetStringUTFChars(env, fName, 0L);
    const char* strFieldSig = (*env)->GetStringUTFChars(env, fSig, 0L);

    jfieldID fieldID = (*env)->GetFieldID(env, clz, strFieldName, strFieldSig);

    (*env)->ReleaseStringUTFChars(env, fName, strFieldName);
    (*env)->ReleaseStringUTFChars(env, fSig, strFieldSig);

    (*env)->SetCharField(env, obj, fieldID, val);
}

/*
 * Class:     org_openorb_orb_rmi_DeserializationKernelNative
 * Method:    nativeSetShortField
 * Signature: (Ljava/lang/Class;Ljava/lang/String;Ljava/lang/Object;SLjava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_org_openorb_orb_rmi_DeserializationKernelNative_nativeSetShortField
  (JNIEnv *env, jclass this, jclass clz, jstring fName, jobject obj, jshort val, jstring fSig)
{
    const char* strFieldName = (*env)->GetStringUTFChars(env, fName, 0L);
    const char* strFieldSig = (*env)->GetStringUTFChars(env, fSig, 0L);

    jfieldID fieldID = (*env)->GetFieldID(env, clz, strFieldName, strFieldSig);

    (*env)->ReleaseStringUTFChars(env, fName, strFieldName);
    (*env)->ReleaseStringUTFChars(env, fSig, strFieldSig);

    (*env)->SetShortField(env, obj, fieldID, val);
}

/*
 * Class:     org_openorb_orb_rmi_DeserializationKernelNative
 * Method:    nativeSetIntField
 * Signature: (Ljava/lang/Class;Ljava/lang/String;Ljava/lang/Object;ILjava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_org_openorb_orb_rmi_DeserializationKernelNative_nativeSetIntField
  (JNIEnv *env, jclass this, jclass clz, jstring fName, jobject obj, jint val, jstring fSig)
{
    const char* strFieldName = (*env)->GetStringUTFChars(env, fName, 0L);
    const char* strFieldSig = (*env)->GetStringUTFChars(env, fSig, 0L);

    jfieldID fieldID = (*env)->GetFieldID(env, clz, strFieldName, strFieldSig);

    (*env)->ReleaseStringUTFChars(env, fName, strFieldName);
    (*env)->ReleaseStringUTFChars(env, fSig, strFieldSig);

    (*env)->SetIntField(env, obj, fieldID, val);
}

/*
 * Class:     org_openorb_orb_rmi_DeserializationKernelNative
 * Method:    nativeSetLongField
 * Signature: (Ljava/lang/Class;Ljava/lang/String;Ljava/lang/Object;JLjava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_org_openorb_orb_rmi_DeserializationKernelNative_nativeSetLongField
  (JNIEnv *env, jclass this, jclass clz, jstring fName, jobject obj, jlong val, jstring fSig)
{
    const char* strFieldName = (*env)->GetStringUTFChars(env, fName, 0L);
    const char* strFieldSig = (*env)->GetStringUTFChars(env, fSig, 0L);

    jfieldID fieldID = (*env)->GetFieldID(env, clz, strFieldName, strFieldSig);

    (*env)->ReleaseStringUTFChars(env, fName, strFieldName);
    (*env)->ReleaseStringUTFChars(env, fSig, strFieldSig);

    (*env)->SetLongField(env, obj, fieldID, val);
}

/*
 * Class:     org_openorb_orb_rmi_DeserializationKernelNative
 * Method:    nativeSetFloatField
 * Signature: (Ljava/lang/Class;Ljava/lang/String;Ljava/lang/Object;FLjava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_org_openorb_orb_rmi_DeserializationKernelNative_nativeSetFloatField
  (JNIEnv *env, jclass this, jclass clz, jstring fName, jobject obj, jfloat val, jstring fSig)
{
    const char* strFieldName = (*env)->GetStringUTFChars(env, fName, 0L);
    const char* strFieldSig = (*env)->GetStringUTFChars(env, fSig, 0L);

    jfieldID fieldID = (*env)->GetFieldID(env, clz, strFieldName, strFieldSig);

    (*env)->ReleaseStringUTFChars(env, fName, strFieldName);
    (*env)->ReleaseStringUTFChars(env, fSig, strFieldSig);

    (*env)->SetFloatField(env, obj, fieldID, val);
}

/*
 * Class:     org_openorb_orb_rmi_DeserializationKernelNative
 * Method:    nativeSetDoubleField
 * Signature: (Ljava/lang/Class;Ljava/lang/String;Ljava/lang/Object;DLjava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_org_openorb_orb_rmi_DeserializationKernelNative_nativeSetDoubleField
  (JNIEnv *env, jclass this, jclass clz, jstring fName, jobject obj, jdouble val, jstring fSig)
{
    const char* strFieldName = (*env)->GetStringUTFChars(env, fName, 0L);
    const char* strFieldSig = (*env)->GetStringUTFChars(env, fSig, 0L);

    jfieldID fieldID = (*env)->GetFieldID(env, clz, strFieldName, strFieldSig);

    (*env)->ReleaseStringUTFChars(env, fName, strFieldName);
    (*env)->ReleaseStringUTFChars(env, fSig, strFieldSig);

    (*env)->SetDoubleField(env, obj, fieldID, val);
}

#ifdef __cplusplus
}
#endif
#endif
